@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous   *
  *                  mode detection and handling.               *
  *                                                             *
- * Version:         1.0.4                                      *
+ * Version:         1.0.5                                      *
  *                                                             *
  * ----------------------------------------------------------- *
  *                                                             *
@@ -486,7 +486,7 @@ int ifMetric( struct ifList *list )
 
 	if( ( lfPtr = strchr( ifIndex, '\n' ) ) == NULL )
         {
-            errHandler( "%s", "ERROR: strchr(): could not process interface metrics data: no newline termination\n" );
+            errHandler( "%s", "ERROR: strchr(): could not process interface metrics data: no newline terminator\n" );
 	    return (-1);
          }
 
@@ -530,7 +530,7 @@ int ifMetric( struct ifList *list )
 
 	if( ( lfPtr = strchr( rxPackets, '\n' ) ) == NULL )
         {
-            errHandler( "%s", "ERROR: strchr(): could not process interface metrics data: no newline termination\n" );
+            errHandler( "%s", "ERROR: strchr(): could not process interface metrics data: no newline terminator\n" );
 	    return (-1);
          }
 
@@ -556,7 +556,7 @@ int ifMetric( struct ifList *list )
 
 	if( ( lfPtr = strchr( txPackets, '\n' ) ) == NULL )
 	{
-            errHandler( "%s", "ERROR: strchr(): could not process interface metrics data: no newline termination\n" );
+            errHandler( "%s", "ERROR: strchr(): could not process interface metrics data: no newline terminator\n" );
 	    return (-1);
 	 }
 
