@@ -31,14 +31,14 @@
  * Project ifchk -- Host based network interface promiscuous *
  *                  mode detection and handling.             *
  *                                                           *
- * Version:         1.0.4                                    *
+ * Version:         1.0.5                                    *
  *                                                           *
  * --------------------------------------------------------- *
  *                                                           *
  * pidfile.c        ifchk file locking subsystem.            *
  *                                                           *
  * Functions:     - Performs file locking operations on the  *
- *                  ifchk PID file, /tmp/.ifchk.pid.         *
+ *                  ifchk PID file, /var/run/ifchk.pid.      *
  *************************************************************/
  
 /**********************
@@ -50,7 +50,7 @@
 
 /************************************************************
  * lockCtl() - Queries, obtains and releases an exclusive   *
- *             write lock on /tmp/.ifchk.pid.               *
+ *             write lock on /var/run/ifchk.pid.            *
  *                                                          *
  * Parameters: lockCmd: File lock operation to perform (one *
  *                      of QUERYLOCK, LOCK or UNLOCK).      *
@@ -67,18 +67,18 @@ int lockCtl( int lockCmd )
     int pidLen = 0;			/* ifchk PID character count. */
 
     /*
-     * Open /tmp/.ifchk.pid write-only/create
+     * Open /var/run/ifchk.pid write-only/create
      * and set its permissions to mode 0600.
      */
-    if( ( pidfilefd = open( "/tmp/.ifchk.pid", O_WRONLY | O_CREAT, PIDMASK ) ) == -1 )
+    if( ( pidfilefd = open( "/var/run/ifchk.pid", O_WRONLY | O_CREAT, PIDMASK ) ) == -1 )
     {
-        errHandler( "ERROR: open(): could not open file /tmp/.ifchk.pid: %s\n",
-                                                              strerror( errno ) );
+        errHandler( "ERROR: open(): could not open file /var/run/ifchk.pid: %s\n",
+                                                                 strerror( errno ) );
         return (-1);
      }
 
     /*
-     * Query /tmp/.ifchk.pid to see if another PID
+     * Query /var/run/ifchk.pid to see if another PID
      * already has a write lock on the entire file.
      * This should be another ifchk instance, if so.
      */
@@ -92,8 +92,8 @@ int lockCtl( int lockCmd )
 
         if( ( fcntl( pidfilefd, F_GETLK, &lock ) ) == -1 )
         {
-            errHandler( "ERROR: fcntl(): could not query lock for file /tmp/.ifchk.pid: %s\n",
-	                                                                     strerror( errno ) );
+            errHandler( "ERROR: fcntl(): could not query lock for file /var/run/ifchk.pid: %s\n",
+	                                                                        strerror( errno ) );
             return (-1);
          }
 
@@ -102,8 +102,8 @@ int lockCtl( int lockCmd )
          */
         if( ( close( pidfilefd ) ) != 0 )
         {
-            errHandler( "ERROR: close(): could not close /tmp/.ifchk.pid: %s\n",
-                                                               strerror( errno ) );
+            errHandler( "ERROR: close(): could not close /var/run/ifchk.pid: %s\n",
+                                                                  strerror( errno ) );
             return (-1);
          }
 
@@ -121,7 +121,7 @@ int lockCtl( int lockCmd )
 
     /*
      * Take out an exclusive write lock on the
-     * whole /tmp/.ifchk.pid file. Getting to
+     * whole /var/run/ifchk.pid file. Getting to
      * this point indicates that we are the only
      * ifchk instance running on this host.
      */
@@ -134,19 +134,18 @@ int lockCtl( int lockCmd )
 
         if( ( fcntl( pidfilefd, F_SETLK, &lock ) ) == -1 )
         {
-            errHandler( "ERROR: fcntl(): could not lock file /tmp/.ifchk.pid: %s\n",
-                                                                   strerror( errno ) );
+            errHandler( "ERROR: fcntl(): could not lock file /var/run/ifchk.pid: %s\n",
+                                                                      strerror( errno ) );
             return (-1);
          }
 
         /*
-         * Truncate /tmp/.ifchk.pid
-         * to zero bytes in size.
+         * Truncate /var/run/ifchk.pid to zero bytes in size.
          */
         if( ftruncate( pidfilefd, 0 ) == -1 )
         {
-            errHandler( "ERROR: ftruncate(): could not truncate file /tmp/.ifchk.pid: %s\n",
-                                                                           strerror( errno ) );
+            errHandler( "ERROR: ftruncate(): could not truncate file /var/run/ifchk.pid: %s\n",
+                                                                              strerror( errno ) );
             return (-1);
          }
 
@@ -161,18 +160,18 @@ int lockCtl( int lockCmd )
          }
 
         /*
-         * Write our PID to /tmp/.ifchk.pid.
+         * Write our PID to /var/run/ifchk.pid.
          */
         if( write( pidfilefd, pidBuf, (size_t)pidLen ) == -1 )
         {
-            errHandler( "ERROR: write(): could not write to file /tmp/.ifchk.pid: %s\n",
-                                                                       strerror( errno ) );
+            errHandler( "ERROR: write(): could not write to file /var/run/ifchk.pid: %s\n",
+                                                                          strerror( errno ) );
             return (-1);
          }
      }
 
     /*
-     * Release the lock on /tmp/.ifchk.pid and delete it.
+     * Release the lock on /var/run/ifchk.pid and delete it.
      */
     else if( lockCmd == UNLOCK )
     { 
@@ -183,8 +182,8 @@ int lockCtl( int lockCmd )
 
         if( ( fcntl( pidfilefd, F_SETLK, &lock ) ) == -1 )
         {
-            errHandler( "ERROR: fcntl(): could not release lock on file /tmp/.ifchk.pid: %s\n",
-	                                                                      strerror( errno ) );
+            errHandler( "ERROR: fcntl(): could not release lock on file /var/run/ifchk.pid: %s\n",
+	                                                                         strerror( errno ) );
             return (-1);
          }
 
@@ -194,18 +193,18 @@ int lockCtl( int lockCmd )
 	 */
         if( ( close( pidfilefd ) ) != 0 )
         {
-            errHandler( "ERROR: close(): could not close /tmp/.ifchk.pid: %s\n",
-                                                               strerror( errno ) );
+            errHandler( "ERROR: close(): could not close /var/run/fchk.pid: %s\n",
+                                                                 strerror( errno ) );
             return (-1);
          }
 
 	/*
 	 * Delete the PID file.
 	 */
-        if( unlink( "/tmp/.ifchk.pid" ) != 0 )
+        if( unlink( "/var/run/ifchk.pid" ) != 0 )
         {
-            errHandler( "ERROR: unlink(): could not remove file /tmp/.ifchk.pid: %s\n",
-                                                                      strerror( errno ) );
+            errHandler( "ERROR: unlink(): could not remove file /var/run/ifchk.pid: %s\n",
+                                                                         strerror( errno ) );
             return (-1);
          }
      }
